@@ -1,11 +1,12 @@
 package Tie::MLDBM::Store::DBI;
 
-use base qw/ Tie::DBI /;
+use Tie::DBI;
 
 use strict;
-use vars qw/ $VERSION /;
+use vars qw/ @ISA $VERSION /;
 
-$VERSION = '1.03';
+@ISA = qw/ Tie::DBI /;
+$VERSION = '1.04';
 
 
 1;
@@ -53,4 +54,4 @@ Copyright 2002 Rob Casey, robau@cpan.org
 
 L<Tie::MLDBM>, L<Tie::DBI>
 
-=cut
\ No newline at end of file
+=cut
